@@ -41,14 +41,17 @@ VKGallery::~VKGallery()
 
 void VKGallery::init()
 {
+    windowHelp = new uihelp(this);
+#ifdef Q_WS_MAEMO_5
+    windowHelp->setAttribute(Qt::WA_Maemo5StackedWindow);
+#endif
+
     //user
     //ui->pushButtonLogout->setIcon(QIcon::fromTheme("general_settings"));
     //ui->pushButtonLogout->setFlat(TRUE);
     ui->pushButtonMe->setIcon(QIcon::fromTheme("general_default_avatar", QIcon(":/res/general_default_avatar.png")));
     ui->pushButtonMe->setStyleSheet("text-align: left; image-position: left;");
 
-
-
     //friends list
     //label
     QIcon icon;
@@ -135,6 +138,7 @@ void VKGallery::init()
     connect(buttonClosePhotos, SIGNAL(clicked()), this, SLOT(hidePhotos()));
     //connect(buttonCloseAlbums, SIGNAL(clicked()), this, SLOT(hideAlbums()));
     connect(ui->actionSettings, SIGNAL(triggered()), this, SLOT(on_actionSettings_toggled()));
+    connect(ui->actionHelp, SIGNAL(triggered()), this, SLOT(help()));
     connect(ui->actionFull_screen, SIGNAL(triggered()), this, SLOT(on_actionFull_screen_toggled()));
 
     // enable sorting
@@ -264,7 +268,10 @@ void VKGallery::updateListFriends(FriendList list, bool isLastUpdate)
     }
 }
 
-
+void VKGallery::help()
+{
+    windowHelp->show();
+}
 
 void VKGallery::refreshFriends()
 {
