@@ -1278,6 +1278,9 @@ void VkTransport::vkDownloadPhotoList(PhotoList list, Photo curPhoto, int neares
     if (nearest < 0)
         return;
 
+    if(list.isEmpty())
+        return;
+
     int count = 0;
 
     QDir dir;
@@ -1304,6 +1307,13 @@ void VkTransport::vkDownloadPhotoList(PhotoList list, Photo curPhoto, int neares
             qDebug() << "download image: start=" << startItem << " i=" << i << " cp=" << cp;
             while (cp < 0)
                 cp += len;
+
+///FIXME
+            while(cp >= list.size())
+                cp -= len;
+
+            qDebug()<< "photo_url = "<< list.at(cp).photo_url << endl;
+
             QString photo_path = vkGenerateFileName(Utils::getPhotoDir(this->driverModule->name), list.at(cp).photo_url);
             QFile file(photo_path);
             if(!file.exists()){
